"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Display = void 0;
class Display {
    constructor(ledController, startIndex, amountOfLeds) {
        this.color = {
            red: 0,
            green: 255,
            blue: 0,
        };
        this.lastColor = {
            red: 0,
            green: 255,
            blue: 0,
        };
        this.isOn = false;
        this.isBlinking = false;
        this.blinkDuration = 500;
        this.ledController = ledController;
        this.startIndex = startIndex;
        this.amountOfLeds = amountOfLeds;
    }
    on(color) {
        this.isOn = true;
        const colorToUse = color ? color : this.color;
        this.lastColor = colorToUse;
        this.ledController.setLeds(this.startIndex, this.amountOfLeds, colorToUse);
    }
    off() {
        this.isOn = false;
        this.ledController.clearLeds(this.startIndex, this.amountOfLeds);
    }
    setColor(color) {
        this.color = color;
        this.lastColor = color;
        if (this.isOn) {
            this.turnBackOn();
        }
    }
    startBlinking(ms, blinkCallback) {
        this.isBlinking = true;
        this.blinkDuration = ms;
        this.blinkCallback = blinkCallback;
        this.blinkOn();
    }
    stopBlinking() {
        this.isBlinking = false;
    }
    render() {
        return this.ledController.render();
    }
    blinkOn() {
        setTimeout(async () => {
            if (!this.isBlinking) {
                return;
            }
            if (this.blinkCallback) {
                this.blinkCallback();
            }
            this.turnBackOn();
            this.blinkOff();
        }, this.blinkDuration);
    }
    blinkOff() {
        setTimeout(async () => {
            if (!this.isBlinking) {
                return;
            }
            if (this.blinkCallback) {
                this.blinkCallback();
            }
            this.off();
            this.blinkOn();
        }, this.blinkDuration);
    }
}
exports.Display = Display;
//# sourceMappingURL=Display.js.map