"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SevenSegmentDisplay = void 0;
const Display_1 = require("./Display");
const Segment_1 = require("./Segment");
const numberOfSegments = 7;
class SevenSegmentDisplay extends Display_1.Display {
    constructor(ledController, startIndex, amountOfLedsPerSegment) {
        super(ledController, startIndex, amountOfLedsPerSegment * numberOfSegments);
        this.segments = [];
        this.lastColors = [];
        this.colors = [];
        this.lastSegmentIndexes = [];
        for (let index = 0; index < numberOfSegments; index++) {
            this.segments.push(new Segment_1.Segment(ledController, startIndex + index * amountOfLedsPerSegment, amountOfLedsPerSegment));
        }
    }
    setMultipleColors(colors) {
        this.colors = colors;
        this.lastColors = colors;
        if (this.isOn) {
            this.turnBackOn();
        }
    }
    off() {
        this.isOn = false;
        for (const segment of this.segments) {
            segment.off();
        }
    }
    showSegments(segmentIndexes, colors) {
        this.isOn = true;
        this.lastSegmentIndexes = segmentIndexes;
        for (let index = 0; index < segmentIndexes.length; index++) {
            const segmentIndex = segmentIndexes[index];
            const color = this.getColorByIndex(colors, index);
            this.segments[segmentIndex].on(color);
            this.lastColor = color;
        }
        this.lastColors = Array.isArray(colors) ? colors : [];
    }
    turnBackOn() {
        this.isOn = true;
        const colors = this.lastColors.length > 0 ? this.lastColors : this.lastColor;
        this.showSegments(this.lastSegmentIndexes, colors);
    }
    getColorByIndex(colors, index) {
        if (!colors) {
            if (this.colors) {
                return this.getColorByIndex(this.colors, index);
            }
            return this.color;
        }
        if (!Array.isArray(colors)) {
            return colors;
        }
        return colors[index % colors.length];
    }
}
exports.SevenSegmentDisplay = SevenSegmentDisplay;
//# sourceMappingURL=SevenSegmentDisplay.js.map